#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-api-data
version: 0.2.2
id: http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
key: httpa_4PIMg2QbRyT0SZyC9tOKTV
license: BSD3
maintainer: Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability: unstable
homepage: http://github.com/fizruk/http-api-data
synopsis: Converting to/from HTTP API data like URL pieces, headers and query parameters.
description:
    Please see README.md
category: Web
author: Nickolay Kudasov <nickolay.kudasov@gmail.com>
exposed: True
exposed-modules:
    Web.HttpApiData Web.HttpApiData.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http-api-data-0.2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/http-api-data-0.2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/http-api-data-0.2.2
hs-libraries: HShttp-api-data-0.2.2-4PIMg2QbRyT0SZyC9tOKTV
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
haddock-interfaces: /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock
haddock-html: /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
